if (CMAKE_VERSION VERSION_LESS 3.1.0)
    message(FATAL_ERROR "Qt 5 WebKit module requires at least CMake version 3.1.0")
endif()

get_filename_component(_qt5WebKit_install_prefix "/opt/local/libexec/qt5/lib/cmake/Qt5WebKit/../../../" ABSOLUTE)

# For backwards compatibility only. Use Qt5WebKit_VERSION instead.
set(Qt5WebKit_VERSION_STRING 5.9.2)

set(Qt5WebKit_LIBRARIES Qt5::WebKit)

macro(_qt5_WebKit_check_file_exists file)
    if(NOT EXISTS "${file}" )
        message(FATAL_ERROR "The imported target \"Qt5::WebKit\" references the file
   \"${file}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    endif()
endmacro()


macro(_populate_WebKit_target_properties Configuration LIB_LOCATION IMPLIB_LOCATION
      IsDebugAndRelease)
    set_property(TARGET Qt5::WebKit APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

    set(imported_location "${_qt5WebKit_install_prefix}/lib/${LIB_LOCATION}")
    _qt5_WebKit_check_file_exists(${imported_location})
    set(_deps
        ${_Qt5WebKit_LIB_DEPENDENCIES}
    )
    set(_static_deps
    )

    set_target_properties(Qt5::WebKit PROPERTIES
        "IMPORTED_LOCATION_${Configuration}" ${imported_location}
        # For backward compatibility with CMake < 2.8.12
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${Configuration}" "${_deps};${_static_deps}"
    )
    set_property(TARGET Qt5::WebKit APPEND PROPERTY INTERFACE_LINK_LIBRARIES
                 "${_deps}"
    )


endmacro()

if (NOT TARGET Qt5::WebKit)

    set(_Qt5WebKit_OWN_INCLUDE_DIRS
      "${_qt5WebKit_install_prefix}/lib/QtWebKit.framework"
      "${_qt5WebKit_install_prefix}/lib/QtWebKit.framework/Headers"
    )
    set(Qt5WebKit_PRIVATE_INCLUDE_DIRS
        "${_qt5WebKit_install_prefix}/lib/QtWebKit.framework/Versions/5/Headers/5.9.2/"
        "${_qt5WebKit_install_prefix}/lib/QtWebKit.framework/Versions/5/Headers/5.9.2/QtWebKit"
    )

    foreach(_dir ${_Qt5WebKit_OWN_INCLUDE_DIRS})
        _qt5_WebKit_check_file_exists(${_dir})
    endforeach()


    set(Qt5WebKit_INCLUDE_DIRS ${_Qt5WebKit_OWN_INCLUDE_DIRS})

    set(Qt5WebKit_DEFINITIONS -DQT_WEBKIT_LIB)
    set(Qt5WebKit_COMPILE_DEFINITIONS QT_WEBKIT_LIB)
    set(_Qt5WebKit_MODULE_DEPENDENCIES "Gui;Network;Core")


    set(Qt5WebKit_OWN_PRIVATE_INCLUDE_DIRS ${Qt5WebKit_PRIVATE_INCLUDE_DIRS})

    set(_Qt5WebKit_FIND_DEPENDENCIES_REQUIRED)
    if (Qt5WebKit_FIND_REQUIRED)
        set(_Qt5WebKit_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5WebKit_FIND_DEPENDENCIES_QUIET)
    if (Qt5WebKit_FIND_QUIETLY)
        set(_Qt5WebKit_DEPENDENCIES_FIND_QUIET QUIET)
    endif()
    set(_Qt5WebKit_FIND_VERSION_EXACT)
    if (Qt5WebKit_FIND_VERSION_EXACT)
        set(_Qt5WebKit_FIND_VERSION_EXACT EXACT)
    endif()

    set(Qt5WebKit_EXECUTABLE_COMPILE_FLAGS "")

    foreach(_module_dep ${_Qt5WebKit_MODULE_DEPENDENCIES})
        if (NOT Qt5${_module_dep}_FOUND)
            find_package(Qt5${_module_dep}
                5.9.2 ${_Qt5WebKit_FIND_VERSION_EXACT}
                ${_Qt5WebKit_DEPENDENCIES_FIND_QUIET}
                ${_Qt5WebKit_FIND_DEPENDENCIES_REQUIRED}
                PATHS "/opt/local/libexec/qt5/lib/cmake/Qt5WebKit/.." NO_DEFAULT_PATH
            )
        endif()

        if (NOT Qt5${_module_dep}_FOUND)
            set(Qt5WebKit_FOUND False)
            return()
        endif()

        list(APPEND Qt5WebKit_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
        list(APPEND Qt5WebKit_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
        list(APPEND Qt5WebKit_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
        list(APPEND Qt5WebKit_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
        list(APPEND Qt5WebKit_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
    endforeach()
    list(REMOVE_DUPLICATES Qt5WebKit_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5WebKit_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5WebKit_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5WebKit_COMPILE_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5WebKit_EXECUTABLE_COMPILE_FLAGS)

    # It can happen that the same FooConfig.cmake file is included when calling find_package()
    # on some Qt component. An example of that is when using a Qt static build with auto inclusion
    # of plugins:
    #
    # Qt5WidgetsConfig.cmake -> Qt5GuiConfig.cmake -> Qt5Gui_QSvgIconPlugin.cmake ->
    # Qt5SvgConfig.cmake -> Qt5WidgetsConfig.cmake ->
    # finish processing of second Qt5WidgetsConfig.cmake ->
    # return to first Qt5WidgetsConfig.cmake ->
    # add_library cannot create imported target Qt5::Widgets.
    #
    # Make sure to return early in the original Config inclusion, because the target has already
    # been defined as part of the second inclusion.
    if(TARGET Qt5::WebKit)
        return()
    endif()

    set(_Qt5WebKit_LIB_DEPENDENCIES "Qt5::Gui;Qt5::Network;Qt5::Core")


    add_library(Qt5::WebKit SHARED IMPORTED)

    set_property(TARGET Qt5::WebKit PROPERTY FRAMEWORK 1)

    set_property(TARGET Qt5::WebKit PROPERTY
      INTERFACE_INCLUDE_DIRECTORIES ${_Qt5WebKit_OWN_INCLUDE_DIRS})
    set_property(TARGET Qt5::WebKit PROPERTY
      INTERFACE_COMPILE_DEFINITIONS QT_WEBKIT_LIB)

    set_property(TARGET Qt5::WebKit PROPERTY INTERFACE_QT_ENABLED_FEATURES )
    set_property(TARGET Qt5::WebKit PROPERTY INTERFACE_QT_DISABLED_FEATURES )

    # Qt 6 forward compatible properties.
    set_property(TARGET Qt5::WebKit
                 PROPERTY QT_ENABLED_PUBLIC_FEATURES
                 )
    set_property(TARGET Qt5::WebKit
                 PROPERTY QT_DISABLED_PUBLIC_FEATURES
                 )
    set_property(TARGET Qt5::WebKit
                 PROPERTY QT_ENABLED_PRIVATE_FEATURES
                 )
    set_property(TARGET Qt5::WebKit
                 PROPERTY QT_DISABLED_PRIVATE_FEATURES
                 )

    set_property(TARGET Qt5::WebKit PROPERTY INTERFACE_QT_PLUGIN_TYPES "")

    set(_Qt5WebKit_PRIVATE_DIRS_EXIST TRUE)
    foreach (_Qt5WebKit_PRIVATE_DIR ${Qt5WebKit_OWN_PRIVATE_INCLUDE_DIRS})
        if (NOT EXISTS ${_Qt5WebKit_PRIVATE_DIR})
            set(_Qt5WebKit_PRIVATE_DIRS_EXIST FALSE)
        endif()
    endforeach()

    if (_Qt5WebKit_PRIVATE_DIRS_EXIST)
        add_library(Qt5::WebKitPrivate INTERFACE IMPORTED)
        set_property(TARGET Qt5::WebKitPrivate PROPERTY
            INTERFACE_INCLUDE_DIRECTORIES ${Qt5WebKit_OWN_PRIVATE_INCLUDE_DIRS}
        )
        set(_Qt5WebKit_PRIVATEDEPS)
        foreach(dep ${_Qt5WebKit_LIB_DEPENDENCIES})
            if (TARGET ${dep}Private)
                list(APPEND _Qt5WebKit_PRIVATEDEPS ${dep}Private)
            endif()
        endforeach()
        set_property(TARGET Qt5::WebKitPrivate PROPERTY
            INTERFACE_LINK_LIBRARIES Qt5::WebKit ${_Qt5WebKit_PRIVATEDEPS}
        )

        # Add a versionless target, for compatibility with Qt6.
        if(NOT "${QT_NO_CREATE_VERSIONLESS_TARGETS}" AND NOT TARGET Qt::WebKitPrivate)
            add_library(Qt::WebKitPrivate INTERFACE IMPORTED)
            set_target_properties(Qt::WebKitPrivate PROPERTIES
                INTERFACE_LINK_LIBRARIES "Qt5::WebKitPrivate"
            )
        endif()
    endif()

    _populate_WebKit_target_properties(RELEASE "QtWebKit.framework/QtWebKit" "" FALSE)




    # In Qt 5.15 the glob pattern was relaxed to also catch plugins not literally named Plugin.
    # Define QT5_STRICT_PLUGIN_GLOB or ModuleName_STRICT_PLUGIN_GLOB to revert to old behavior.
    if (QT5_STRICT_PLUGIN_GLOB OR Qt5WebKit_STRICT_PLUGIN_GLOB)
        file(GLOB pluginTargets "/opt/local/libexec/qt5/lib/cmake/Qt5WebKit/Qt5WebKit_*Plugin.cmake")
    else()
        file(GLOB pluginTargets "/opt/local/libexec/qt5/lib/cmake/Qt5WebKit/Qt5WebKit_*.cmake")
    endif()

    macro(_populate_WebKit_plugin_properties Plugin Configuration PLUGIN_LOCATION
          IsDebugAndRelease)
        set_property(TARGET Qt5::${Plugin} APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

        set(imported_location "${_qt5WebKit_install_prefix}/plugins/${PLUGIN_LOCATION}")
        _qt5_WebKit_check_file_exists(${imported_location})
        set_target_properties(Qt5::${Plugin} PROPERTIES
            "IMPORTED_LOCATION_${Configuration}" ${imported_location}
        )

    endmacro()

    if (pluginTargets)
        foreach(pluginTarget ${pluginTargets})
            include(${pluginTarget})
        endforeach()
    endif()



    _qt5_WebKit_check_file_exists("/opt/local/libexec/qt5/lib/cmake/Qt5WebKit/Qt5WebKitConfigVersion.cmake")
endif()

# Add a versionless target, for compatibility with Qt6.
if(NOT "${QT_NO_CREATE_VERSIONLESS_TARGETS}" AND TARGET Qt5::WebKit AND NOT TARGET Qt::WebKit)
    add_library(Qt::WebKit INTERFACE IMPORTED)
    set_target_properties(Qt::WebKit PROPERTIES
        INTERFACE_LINK_LIBRARIES "Qt5::WebKit"
    )
endif()
